Improve this Doc View Source

Specify custom behavior on mouseover event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-mouseover
        ng-mouseover="expression">
      ...
      </ng-mouseover>

- as attribute:

      <ANY
        ng-mouseover="expression">
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngMouseover | expression | Expression to evaluate upon mouseover. (Event object is available as `$event`)

## Examples

    <button ng-mouseover="count = count + 1" ng-init="count=0">
      Increment (when mouse is over)
    </button>
    count: {{count}}